export declare const geojsonSchema: {
    title: string;
    type: string;
    required: string[];
    oneOf: {
        $ref: string;
    }[];
    definitions: {
        Position: {
            type: string;
            minItems: number;
            maxItems: number;
            items: {
                type: string;
            };
        };
        Point: {
            type: string;
            required: string[];
            properties: {
                type: {
                    enum: string[];
                };
                coordinates: {
                    $ref: string;
                };
                bbox: {
                    type: string;
                    minItems: number;
                    maxItems: number;
                    items: {
                        type: string;
                    };
                };
            };
        };
        MultiPoint: {
            type: string;
            required: string[];
            properties: {
                type: {
                    enum: string[];
                };
                coordinates: {
                    type: string;
                    items: {
                        $ref: string;
                    };
                };
                bbox: {
                    type: string;
                    minItems: number;
                    maxItems: number;
                    items: {
                        type: string;
                    };
                };
            };
        };
        LineString: {
            type: string;
            required: string[];
            properties: {
                type: {
                    enum: string[];
                };
                coordinates: {
                    type: string;
                    minItems: number;
                    items: {
                        $ref: string;
                    };
                };
                bbox: {
                    type: string;
                    minItems: number;
                    maxItems: number;
                    items: {
                        type: string;
                    };
                };
            };
        };
        MultiLineString: {
            type: string;
            required: string[];
            properties: {
                type: {
                    enum: string[];
                };
                coordinates: {
                    type: string;
                    items: {
                        type: string;
                        minItems: number;
                        items: {
                            $ref: string;
                        };
                    };
                };
                bbox: {
                    type: string;
                    minItems: number;
                    maxItems: number;
                    items: {
                        type: string;
                    };
                };
            };
        };
        Polygon: {
            type: string;
            required: string[];
            properties: {
                type: {
                    enum: string[];
                };
                coordinates: {
                    type: string;
                    items: {
                        type: string;
                        minItems: number;
                        items: {
                            $ref: string;
                        };
                    };
                };
                bbox: {
                    type: string;
                    minItems: number;
                    maxItems: number;
                    items: {
                        type: string;
                    };
                };
            };
        };
        MultiPolygon: {
            type: string;
            required: string[];
            properties: {
                type: {
                    enum: string[];
                };
                coordinates: {
                    type: string;
                    items: {
                        type: string;
                        items: {
                            type: string;
                            minItems: number;
                            items: {
                                $ref: string;
                            };
                        };
                    };
                };
                bbox: {
                    type: string;
                    minItems: number;
                    maxItems: number;
                    items: {
                        type: string;
                    };
                };
            };
        };
        GeometryCollection: {
            type: string;
            required: string[];
            properties: {
                type: {
                    enum: string[];
                };
                geometries: {
                    type: string;
                    items: {
                        oneOf: {
                            $ref: string;
                        }[];
                    };
                };
                bbox: {
                    type: string;
                    minItems: number;
                    maxItems: number;
                    items: {
                        type: string;
                    };
                };
            };
        };
        Feature: {
            type: string;
            required: string[];
            properties: {
                type: {
                    enum: string[];
                };
                geometry: {
                    oneOf: ({
                        type: string;
                        $ref?: undefined;
                    } | {
                        $ref: string;
                        type?: undefined;
                    })[];
                };
                properties: {
                    oneOf: {
                        type: string;
                    }[];
                };
                bbox: {
                    type: string;
                    minItems: number;
                    maxItems: number;
                    items: {
                        type: string;
                    };
                };
            };
        };
        FeatureCollection: {
            type: string;
            required: string[];
            properties: {
                type: {
                    enum: string[];
                };
                features: {
                    type: string;
                    items: {
                        $ref: string;
                    };
                };
                bbox: {
                    type: string;
                    minItems: number;
                    maxItems: number;
                    items: {
                        type: string;
                    };
                };
            };
        };
    };
};
